tdl.event.MouseDown

Package tdl :: Module event :: Class MouseDown |
[frames] | no frames]

# Class MouseDown

source code

      object --+
               |
           Event --+
                   |
    MouseButtonEvent --+
                       |
                      MouseDown

Fired when a mouse button is pressed.

Instance Methods
__init__(self, button, pos, cell) x.__init__(...) initializes x; see help(type(x)) for signature (Inherited from tdl.event.MouseButtonEvent) | source code
__repr__(self) List an events public attributes when printed. (Inherited from tdl.event.Event) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| type = ``'``MOUSEDOWN``'`` String constant representing the type of event.

Instance Variables
string | button Can be one of 'LEFT', 'MIDDLE', 'RIGHT', 'SCROLLUP', 'SCROLLDOWN' (Inherited from tdl.event.MouseButtonEvent)
(int, int) | cell (x, y) position of the mouse snapped to a cell on the root console (Inherited from tdl.event.MouseButtonEvent)
(int, int) | pos (x, y) position of the mouse on the screen (Inherited from tdl.event.MouseButtonEvent)

Properties
Inherited from `object`: `__class__`